@@ -9,11 +9,12 @@ import (
 	"os"
 	"os/signal"
 	"path/filepath"
+	gruntime "runtime"
 	"sort"
 	"strings"
 	"time"
 
-	_ "github.com/containers/libpod/pkg/hooks/0.1.0"
+	_ "github.com/containers/libpod/v2/pkg/hooks/0.1.0"
 	"github.com/containers/storage/pkg/reexec"
 	"github.com/cri-o/cri-o/internal/criocli"
 	"github.com/cri-o/cri-o/internal/log"
@@ -45,7 +46,7 @@ func writeCrioGoroutineStacks() {
 
 func catchShutdown(ctx context.Context, cancel context.CancelFunc, gserver *grpc.Server, sserver *server.Server, hserver *http.Server, signalled *bool) {
 	sig := make(chan os.Signal, 2048)
-	signal.Notify(sig, signals.Interrupt, signals.Term, unix.SIGUSR1, unix.SIGPIPE, signals.Hup)
+	signal.Notify(sig, signals.Interrupt, signals.Term, unix.SIGUSR1, unix.SIGUSR2, unix.SIGPIPE, signals.Hup)
 	go func() {
 		for s := range sig {
 			logrus.WithFields(logrus.Fields{
@@ -55,6 +56,9 @@ func catchShutdown(ctx context.Context, cancel context.CancelFunc, gserver *grpc
 			case unix.SIGUSR1:
 				writeCrioGoroutineStacks()
 				continue
+			case unix.SIGUSR2:
+				gruntime.GC()
+				continue
 			case unix.SIGPIPE:
 				continue
 			case signals.Interrupt:
@@ -237,28 +241,6 @@ func main() {
 			logrus.Fatal(err)
 		}
 
-		if config.CleanShutdownFile != "" {
-			// clear out the shutdown file
-			if err := os.Remove(config.CleanShutdownFile); err != nil && !os.IsNotExist(err) {
-				logrus.Error(err)
-			}
-
-			// Write "$CleanShutdownFile".supported to show crio-wipe that
-			// we should be wiping if the CleanShutdownFile wasn't found.
-			// This protects us from wiping after an upgrade from a version that don't support
-			// CleanShutdownFile.
-			f, err := os.Create(config.CleanShutdownSupportedFileName())
-			if err != nil {
-				logrus.Errorf("Writing clean shutdown supported file: %v", err)
-			}
-			f.Close()
-
-			// and sync the changes to disk
-			if err := utils.SyncParent(config.CleanShutdownFile); err != nil {
-				logrus.Errorf("failed to sync parent directory of clean shutdown file: %v", err)
-			}
-		}
-
 		runtime.RegisterRuntimeServiceServer(grpcServer, service)
 		runtime.RegisterImageServiceServer(grpcServer, service)
 
@@ -284,7 +266,7 @@ func main() {
 		grpcL := m.MatchWithWriters(cmux.HTTP2MatchHeaderFieldSendSettings("content-type", "application/grpc"))
 		httpL := m.Match(cmux.HTTP1Fast())
 
-		infoMux := service.GetInfoMux()
+		infoMux := service.GetInfoMux(c.Bool("enable-profile-unix-socket"))
 		httpServer := &http.Server{
 			Handler:     infoMux,
 			ReadTimeout: 5 * time.Second,
@@ -345,6 +327,9 @@ func main() {
 		return nil
 	}
 
+	// Log our version early at startup
+	version.LogVersion()
+
 	if err := app.Run(os.Args); err != nil {
 		logrus.Fatal(err)
 	}
