@@ -158,6 +158,9 @@ func mergeConfig(config *libconfig.Config, ctx *cli.Context) error {
 	if ctx.IsSet("apparmor-profile") {
 		config.ApparmorProfile = ctx.String("apparmor-profile")
 	}
+	if ctx.IsSet("irqbalance-config-file") {
+		config.IrqBalanceConfigFile = ctx.String("irqbalance-config-file")
+	}
 	if ctx.IsSet("cgroup-manager") {
 		config.CgroupManagerName = ctx.String("cgroup-manager")
 	}
@@ -530,6 +533,11 @@ func getCrioFlags(defConf *libconfig.Config) []cli.Flag {
 			Value:   defConf.ApparmorProfile,
 			EnvVars: []string{"CONTAINER_APPARMOR_PROFILE"},
 		},
+		&cli.StringFlag{
+			Name:  "irqbalance-config-file",
+			Usage: "The irqbalance service config file which is used by CRI-O.",
+			Value: defConf.IrqBalanceConfigFile,
+		},
 		&cli.BoolFlag{
 			Name:    "selinux",
 			Usage:   fmt.Sprintf("Enable selinux support (default: %t)", defConf.SELinux),
